@@ -22,15 +22,15 @@ Next variants and unpacking with related checks.
 
 from nuitka.PythonVersions import python_version
 
+from .CodeHelpers import generateChildExpressionsCode, generateExpressionCode
 from .ErrorCodes import (
     getErrorExitCode,
     getErrorExitReleaseCode,
     getFrameVariableTypeDescriptionCode,
     getReleaseCode
 )
-from .Helpers import generateChildExpressionsCode, generateExpressionCode
 from .Indentation import indented
-from .LineNumberCodes import getLineNumberUpdateCode
+from .LineNumberCodes import getErrorLineNumberUpdateCode
 from .PythonAPICodes import generateCAPIObjectCode
 from .templates.CodeTemplatesIterators import (
     template_iterator_check,
@@ -103,7 +103,7 @@ def getBuiltinLoopBreakNextCode(to_name, value, emit, context):
                 2
             ),
             "line_number_code"     : indented(
-                getLineNumberUpdateCode(context),
+                getErrorLineNumberUpdateCode(context),
                 2
             ),
             "exception_target"     : context.getExceptionEscape()
@@ -184,6 +184,10 @@ def generateUnpackCheckCode(statement, emit, context):
     release_code = getErrorExitReleaseCode(context)
     var_description_code = getFrameVariableTypeDescriptionCode(context)
 
+    old_source_ref = context.setCurrentSourceCodeReference(
+        statement.getSourceReference()
+    )
+
     emit(
         template_iterator_check % {
             "iterator_name"          : iterator_name,
@@ -191,9 +195,11 @@ def generateUnpackCheckCode(statement, emit, context):
             "count"                  : statement.getCount(),
             "exception_exit"         : context.getExceptionEscape(),
             "release_temps_1"        : indented(release_code, 3),
+            "line_number_code_1"     : indented(getErrorLineNumberUpdateCode(context),3),
             "var_description_code_1" : indented(var_description_code, 3),
             "release_temps_2"        : indented(release_code),
             "var_description_code_2" : indented(var_description_code),
+            "line_number_code_2"     : indented(getErrorLineNumberUpdateCode(context)),
         }
     )
 
@@ -203,6 +209,10 @@ def generateUnpackCheckCode(statement, emit, context):
         context      = context
     )
 
+    context.setCurrentSourceCodeReference(
+        old_source_ref
+    )
+
 
 def generateBuiltinNext2Code(to_name, expression, emit, context):
     generateCAPIObjectCode(
